@@ -195,17 +195,20 @@ class RobotPulse:
         )
         return self._api.set_position(target_position, **motion_parameters)
 
+    def status_failure(self):
+        return self._api.status_failure()
+
     @deprecated(reason="You should use status() method", version="1.6.0")
     def status_motion(self):
         result = self._api.status_motion()
         self.logger.debug(result)
         return result
-    
+
     def status(self):
         result = self._api.status()
         self.logger.debug(result)
         return result
-    
+
     def status_motors(self):
         return self._api.status_motors()
 
